import requests
from requests.auth import HTTPBasicAuth
from sentry_sdk import capture_exception


def jira_project_issue_summary(email, api_token, project_key, hostname):
    try:
        auth = HTTPBasicAuth(email, api_token)
        headers = {"Accept": "application/json"}

        # Check API version for Jira.
        test_url_v3 = f"https://{hostname}/rest/api/3/project/{project_key}"
        test_url_v2 = f"https://{hostname}/rest/api/2/project/{project_key}"

        # Try API v3 if not valid than use API v2
        response = requests.get(test_url_v3, headers=headers, auth=auth)
        if response.status_code == 200:
            api_ver = "3"
        else:
            api_ver = "2"

        issue_url = f"https://{hostname}/rest/api/{api_ver}/search?jql=project={project_key} AND issuetype=Story"
        issue_response = requests.request(
            "GET", issue_url, headers=headers, auth=auth
        ).json()["total"]

        module_url = f"https://{hostname}/rest/api/{api_ver}/search?jql=project={project_key} AND issuetype=Epic"
        module_response = requests.request(
            "GET", module_url, headers=headers, auth=auth
        ).json()["total"]

        status_url = f"https://{hostname}/rest/api/{api_ver}/status/?jql=project={project_key}"
        status_response = requests.request(
            "GET", status_url, headers=headers, auth=auth
        ).json()

        if api_ver == "3":
            labels_url = f"https://{hostname}/rest/api/{api_ver}/label/?jql=project={project_key}"
            labels_response = requests.request(
                "GET", labels_url, headers=headers, auth=auth
            ).json()["total"]
        else:
            labels_url = f"https://{hostname}/rest/api/{api_ver}/jql/autocompletedata/suggestions?fieldName=labels"
            labels_response = requests.request(
                "GET", labels_url, headers=headers, auth=auth
            ).json()

        if api_ver == "3":
            users_url = (
                f"https://{hostname}/rest/api/{api_ver}/users/search?jql=project={project_key}"
            )
        else:
            users_url = f"https://{hostname}/rest/api/{api_ver}/user/search?username=."
        users_response = requests.request(
            "GET", users_url, headers=headers, auth=auth
        ).json()
        if api_ver == "3":
            return {
                "issues": issue_response,
                "modules": module_response,
                "labels": labels_response,
                "states": len(status_response),
                "users": (
                    [
                        user
                        for user in users_response
                        if user.get("accountType") == "atlassian"
                    ]
                ),
            }
        else:
            return {
                "issues": issue_response,
                "modules": module_response,
                "labels": labels_response,
                "states": len(status_response),
                "users": users_response
            }
    except Exception as e:
        capture_exception(e)
        return {"error": "Something went wrong could not fetch information from jira"}
